import { __decorate } from "tslib";
import { neutralLayerCardContainer, neutralLayer1, neutralLayer2, neutralLayer4, accentFillHover, } from '@microsoft/fast-components';
import { FASTElement, observable, css, customElement } from '@microsoft/fast-element';
import { composedParent } from '@microsoft/fast-foundation';
import { stylesAnimation } from '../../styles';
import { template } from './theme-property-panel.template';
const findProvider = (element) => {
    let current = element;
    while (current) {
        if (current.tagName === 'FOUNDATION-ZERO-DESIGN-SYSTEM') {
            return current;
        }
        current = composedParent(current);
    }
    return null;
};
const styles = css `
  ${stylesAnimation}

  :host {
    --section-spacing: 8px;
    --theme-property-panel-width: 330px;
  }

  fast-card {
    --card-width: 100%;
    --elevation: 0;
    position: fixed;
    overflow: auto;
    right: 0;
    top: 0;
    bottom: 0;
    background-color: ${neutralLayer4};
    border-left: 1px solid var(--neutral-outline-rest);
    border-radius: 0;
    padding: 4px 8px;
    width: var(--theme-property-panel-width);
    transition: var(animation-ease-in-fast);
  }

  fast-accordion {
    background-color: ${neutralLayerCardContainer};
    border: calc(var(--outline-width) * 1px) solid var(--neutral-outline-rest);
    border-radius: calc(var(--corner-radius) * 1px);
    box-shadow: 0 0.5px 0.5px 0 var(--neutral-outline-rest);
    margin-bottom: var(--section-spacing);
    padding-bottom: -1px;
    overflow: hidden;
    transition: var(animation-ease-in-fast);
  }

  fast-accordion-item {
    border: none;
    box-sizing: border-box;
    padding: 0;
  }

  fast-accordion-item::part(button):focus-within::before {
    border: none;
    background-color: ${neutralLayer2};
  }

  fast-accordion-item::part(heading) {
    background-color: ${neutralLayer1};
  }

  fast-accordion-item.expanded::part(region) {
    margin-bottom: 8px;
    padding: 8px 16px;
    border-top: calc(var(--outline-width) * 1px) solid var(--neutral-outline-rest);
  }

  fast-accordion-item::part(button) {
    background-color: ${neutralLayer1};
    margin: -1px 0 0;
    padding: 0 12px;
  }

  fast-accordion-item::part(button):hover {
    color: ${accentFillHover};
  }

  fast-accordion-item > h3 {
    font-size: calc(var(--type-ramp-base-font-size) / 4 * var(--design-unit));
    font-weight: 400;
    transition: var(animation-ease-in-fast);
    user-select: none;
  }

  fast-slider {
    margin-bottom: 28px;
  }

  fast-slider-label {
    font-size: var(--type-ramp-minus-2-font-size);
  }

  fast-text-field::part(root) {
    height: 40px;
    transition: var(animation-ease-in-fast);
  }

  fast-text-field::part(control) {
    padding: 0 4px 0 12px;
  }

  header {
    background-color: ${neutralLayer4};
    border-bottom: calc(var(--outline-width) * 1px) solid var(--neutral-outline-rest);
    margin: -4px -8px calc(var(--section-spacing) * 2) -8px;
    padding: 12px 16px;
    transition: var(animation-ease-in-fast);
  }

  .properties-heading {
    font-size: calc(var(--type-ramp-base-font-size) / 4 * var(--design-unit));
    user-select: none;
  }

  input[type='color'] {
    height: 36px;
    margin-top: 4px;
    padding: 0 2px;
  }

  fast-text-field.compact-number {
    margin-top: 4px;
    width: 80px;
  }

  .accordion-top-in-set {
    border-bottom: 0;
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    box-shadow: none;
    margin-bottom: 0;
  }

  .accordion-top-in-set-of-two {
    border-bottom-left-radius: 0;
    border-bottom-right-radius: 0;
    box-shadow: none;
    margin-bottom: 0;
  }

  .accordion-middle-of-set {
    border-radius: 0;
    box-shadow: none;
    margin-bottom: 0;
  }

  .accordion-bottom-in-set {
    border-top: 0;
    border-top-left-radius: 0;
    border-top-right-radius: 0;
  }
`;
// .withBehaviors(
//         neutralLayerCardContainer.createBehavior(),
//         neutralLayer1.createBehavior(),
//         neutralLayer2.createBehavior(),
//         neutralLayer4.createBehavior(),
//         accentFillHover.createBehavior(),
//     );
let ThemePropertyPanel = class ThemePropertyPanel extends FASTElement {
    connectedCallback() {
        this.provider = findProvider(this);
        super.connectedCallback();
    }
};
__decorate([
    observable
], ThemePropertyPanel.prototype, "provider", void 0);
ThemePropertyPanel = __decorate([
    customElement({
        name: 'theme-property-panel',
        template,
        styles,
    })
], ThemePropertyPanel);
export { ThemePropertyPanel };
